@@ -41,11 +41,12 @@ extern "C"
 
 #include <locale.h>
 
-#include <compiz-core.h>
 #include <ccs.h>
 #include "ccs-private.h"
 }
 
+#include <core/core.h>
+
 extern int xmlLoadExtDtdDefaultValue;
 
 static const char *
@@ -507,15 +508,13 @@ initActionInfoPB (CCSSettingInfo * i, const OptionMetadata & option)
 static void
 addOptionForPluginPB (CCSPlugin * plugin,
 		      const char * name,
-		      Bool isScreen,
-		      unsigned int screen,
 		      const StringList & groups,
 		      const StringList & subgroups,
 		      const OptionMetadata & option)
 {
     CCSSetting *setting;
 
-    if (ccsFindSetting (plugin, name, isScreen, screen))
+    if (ccsFindSetting (plugin, name))
     {
 	fprintf (stderr, "[ERROR]: Option \"%s\" already defined\n", name);
 	return;
@@ -526,8 +525,6 @@ addOptionForPluginPB (CCSPlugin * plugin,
 	return;
 
     setting->parent = plugin;
-    setting->isScreen = isScreen;
-    setting->screenNum = screen;
     setting->isDefault = TRUE;
     setting->name = strdup (name);
 
@@ -666,7 +663,6 @@ addOptionForPluginPB (CCSPlugin * plugin,
 
 static void
 addOptionFromPB (CCSPlugin * plugin,
-		 Bool isScreen,
 		 const StringList & groups,
 		 const StringList & subgroups,
 		 const OptionMetadata & option)
@@ -681,15 +677,8 @@ addOptionFromPB (CCSPlugin * plugin,
     if (!strlen (name) || readonly)
 	return;
 
-    if (isScreen)
-    {
-	for (unsigned i = 0; i < plugin->context->numScreens; i++)
-	    addOptionForPluginPB (plugin, name, TRUE,
-				  plugin->context->screens[i],
-				  groups, subgroups, option);
-    }
-    else
-	addOptionForPluginPB (plugin, name, FALSE, 0, groups, subgroups, option);
+    addOptionForPluginPB (plugin, name,
+			  groups, subgroups, option);
 }
 
 static void
@@ -698,19 +687,6 @@ initOptionsFromPB (CCSPlugin * plugin,
 {
     int numOpt, i;
 
-    if (pluginPB.has_display ())
-    {
-	const ScreenMetadata &displayPB = pluginPB.display ();
-
-	// Display options
-	numOpt = displayPB.option_size ();
-	for (i = 0; i < numOpt; i++)
-	    addOptionFromPB (plugin, FALSE,
-			     displayPB.group_desc (),
-			     displayPB.subgroup_desc (),
-			     displayPB.option (i));
-    }
-
     if (pluginPB.has_screen ())
     {
 	const ScreenMetadata &screenPB = pluginPB.screen ();
@@ -718,7 +694,7 @@ initOptionsFromPB (CCSPlugin * plugin,
 	// Screen options
 	numOpt = screenPB.option_size ();
 	for (i = 0; i < numOpt; i++)
-	    addOptionFromPB (plugin, TRUE,
+	    addOptionFromPB (plugin,
 			     screenPB.group_desc (),
 			     screenPB.subgroup_desc (),
 			     screenPB.option (i));
@@ -751,9 +727,6 @@ addStringExtensionFromPB (CCSPlugin * plugin,
     if (!extension)
 	return;
 
-    extension->isScreen = !(extensionPB.has_display () &&
-			    extensionPB.display ());
-
     extension->restriction = NULL;
 
     extension->basePlugin = strdup (extensionPB.base_plugin ().c_str ());
@@ -1004,6 +977,7 @@ getOptionType (const char *name)
 	{ "match", TypeMatch },
 	{ "list", TypeList }
     };
+
     for (unsigned i = 0; i < sizeof (map) / sizeof (map[0]); i++)
 	if (strcasecmp (name, map[i].name) == 0)
 	    return map[i].type;
@@ -1920,7 +1894,7 @@ createProtoBufCacheDir ()
 	metadataCacheDir = cacheBaseDir;
 	if (metadataCacheDir[metadataCacheDir.length () - 1] != '/')
 	    metadataCacheDir += "/";
-	metadataCacheDir += "compizconfig";
+	metadataCacheDir += "compizconfig-1";
 	std::string metadataCacheFileDummy = metadataCacheDir + "/dummy";
 
 	// Create cache dir
@@ -1947,8 +1921,6 @@ addOptionForPlugin (CCSPlugin * plugin,
 		    char * name,
 		    char * type,
 		    Bool isReadonly,
-		    Bool isScreen,
-		    unsigned int screen,
 		    xmlNode * node,
 		    void * groupListPBv,
 		    void * subgroupListPBv,
@@ -1958,7 +1930,7 @@ addOptionForPlugin (CCSPlugin * plugin,
     int num = 0;
     CCSSetting *setting;
 
-    if (ccsFindSetting (plugin, name, isScreen, screen))
+    if (ccsFindSetting (plugin, name))
     {
 	fprintf (stderr, "[ERROR]: Option \"%s\" already defined\n", name);
 	return;
@@ -1972,8 +1944,6 @@ addOptionForPlugin (CCSPlugin * plugin,
 	return;
 
     setting->parent = plugin;
-    setting->isScreen = isScreen;
-    setting->screenNum = screen;
     setting->isDefault = TRUE;
     setting->name = strdup (name);
 
@@ -2146,7 +2116,6 @@ addOptionForPlugin (CCSPlugin * plugin,
 static void
 addOptionFromXMLNode (CCSPlugin * plugin,
 		      xmlNode * node,
-		      Bool isScreen,
 		      void * groupListPBv,
 		      void * subgroupListPBv,
 		      void * optionPBv)
@@ -2182,18 +2151,9 @@ addOptionFromXMLNode (CCSPlugin * plugin,
 	return;
     }
 
-    if (isScreen)
-    {
-	for (unsigned i = 0; i < plugin->context->numScreens; i++)
-	    addOptionForPlugin (plugin, name, type, isReadonly, TRUE,
-				plugin->context->screens[i], node,
-				groupListPBv, subgroupListPBv, optionPBv);
-    }
-    else
-    {
-	addOptionForPlugin (plugin, name, type, isReadonly, FALSE, 0, node,
-			    groupListPBv, subgroupListPBv, optionPBv);
-    }
+    addOptionForPlugin (plugin, name, type, isReadonly, node,
+			groupListPBv, subgroupListPBv, optionPBv);
+
     free (name);
     free (type);
 
@@ -2202,10 +2162,9 @@ addOptionFromXMLNode (CCSPlugin * plugin,
 }
 
 static void
-initDisplayScreenFromRootNode (CCSPlugin * plugin,
-			       xmlNode * node,
-			       Bool isScreen,
-			       void * pluginPBv)
+initScreenFromRootNode (CCSPlugin * plugin,
+			xmlNode * node,
+			void * pluginPBv)
 {
     xmlNode **nodes;
     xmlNode **optNodes;
@@ -2213,8 +2172,7 @@ initDisplayScreenFromRootNode (CCSPlugin * plugin,
     void *groupListPBv = NULL;
     void *subgroupListPBv = NULL;
 
-    nodes = getNodesFromXPath (node->doc, node,
-			       (isScreen ? "screen" : "display"), &num);
+    nodes = getNodesFromXPath (node->doc, node, "options", &num);
     if (!num)
 	return;
 
@@ -2224,9 +2182,7 @@ initDisplayScreenFromRootNode (CCSPlugin * plugin,
     if (pluginPBv)
     {
 	PluginMetadata *pluginPB = (PluginMetadata *) pluginPBv;
-	screenPB = (isScreen ?
-		    pluginPB->mutable_screen () :
-		    pluginPB->mutable_display ());
+	screenPB = pluginPB->mutable_screen ();
 	groupListPBv = screenPB->mutable_group_desc ();
 	subgroupListPBv = screenPB->mutable_subgroup_desc ();
     }
@@ -2244,7 +2200,7 @@ initDisplayScreenFromRootNode (CCSPlugin * plugin,
 	    if (screenPB)
 		optionPBv = screenPB->add_option ();
     #endif
-	    addOptionFromXMLNode (plugin, optNodes[i], isScreen,
+	    addOptionFromXMLNode (plugin, optNodes[i],
 				  groupListPBv, subgroupListPBv, optionPBv);
 	}
 
@@ -2258,11 +2214,8 @@ initOptionsFromRootNode (CCSPlugin * plugin,
 			 xmlNode * node,
 			 void * pluginPBv)
 {
-    // For display
-    initDisplayScreenFromRootNode (plugin, node, FALSE, pluginPBv);
-
-    // For screen
-    initDisplayScreenFromRootNode (plugin, node, TRUE, pluginPBv);
+    // For all optiond
+    initScreenFromRootNode (plugin, node, pluginPBv);
 }
 
 static void
@@ -2307,20 +2260,12 @@ addStringExtensionFromXMLNode (CCSPlugin * plugin,
     CCSStrExtension *extension;
     char *name;
     char *value;
-    char *isDisplay;
     void * stringListPBv = NULL;
 
     extension = (CCSStrExtension *) calloc (1, sizeof (CCSStrExtension));
     if (!extension)
 	return;
 
-    isDisplay = getStringFromXPath (node->doc, node, "@display");
-
-    extension->isScreen = !(isDisplay && !strcmp (isDisplay, "true"));
-
-    if (isDisplay)
-	free (isDisplay);
-
     extension->restriction = NULL;
 
     extension->basePlugin = getStringFromXPath (node->doc, node, "@base_plugin");
@@ -2332,7 +2277,6 @@ addStringExtensionFromXMLNode (CCSPlugin * plugin,
     if (extensionPBv)
     {
 	extensionPB = (ExtensionMetadata *) extensionPBv;
-	extensionPB->set_display (!extension->isScreen);
 	extensionPB->set_base_plugin (extension->basePlugin);
 	stringListPBv = extensionPB->mutable_base_option ();
     }
@@ -2578,7 +2522,7 @@ addCoreSettingsFromXMLNode (CCSContext * context,
     if (file)
 	pPrivate->xmlFile = strdup (file);
 
-    pPrivate->xmlPath = strdup ("/compiz/core");
+    pPrivate->xmlPath = strdup ("/compiz/plugin[@name='core']");
     plugin->context = context;
     plugin->name = strdup ("core");
     plugin->category = strdup ("General");
@@ -2711,7 +2655,7 @@ loadPluginFromXML (CCSContext * context,
     int num;
     Bool success = FALSE;
 
-    nodes = getNodesFromXPath (doc, NULL, "/compiz/core", &num);
+    nodes = getNodesFromXPath (doc, NULL, "/compiz/plugin[@name='core']", &num);
     if (num)
     {
 	success = addCoreSettingsFromXMLNode (context, nodes[0], filename,
@@ -2812,9 +2756,9 @@ loadPluginFromXMLFile (CCSContext * context, char *xmlName, char *xmlDirPath)
 		else
 		    addPluginFromPB (context, persistentPluginBriefPB.info (),
 				     pbFilePath, xmlFilePath);
-		
+    
 		updatePBFilePath (context, name, pbFilePath);
-		
+    
 		free (xmlFilePath);
 		free (pbFilePath);
 		free (name);
@@ -2825,6 +2769,7 @@ loadPluginFromXMLFile (CCSContext * context, char *xmlName, char *xmlDirPath)
 		removePB = TRUE;
 	    }
 	}
+
 	persistentPluginBriefPB.Clear ();
 	pluginInfoPBv = persistentPluginBriefPB.mutable_info ();
     }
@@ -2871,6 +2816,12 @@ loadPluginsFromXMLFiles (CCSContext * context, char *path)
 
     if (!path)
 	return;
+#if defined(HAVE_SCANDIR_POSIX)
+ // POSIX (2008) defines the comparison function like this:
+ #define scandir(a,b,c,d) scandir((a), (b), (c), (int(*)(const dirent **, const dirent **))(d));
+#else
+ #define scandir(a,b,c,d) scandir((a), (b), (c), (int(*)(const void*,const void*))(d));
+#endif
 
     nFile = scandir (path, &nameList, pluginXMLFilter, NULL);
 
@@ -2986,8 +2937,7 @@ ccsLoadPlugin (CCSContext * context, char *name)
 	char *home = getenv ("HOME");
 	if (home && strlen (home))
 	{
-	    char *home = getenv ("HOME");
-	    asprintf (&xmlDirPath, "%s/.compiz/metadata", home);
+	    asprintf (&xmlDirPath, "%s/.compiz-1/metadata", home);
 	    if (xmlDirPath)
 	    {
 		loadPluginFromXMLFile (context, xmlName, xmlDirPath);
@@ -3015,7 +2965,7 @@ ccsLoadPlugins (CCSContext * context)
     if (home && strlen (home))
     {
 	char *homeplugins = NULL;
-	asprintf (&homeplugins, "%s/.compiz/metadata", home);
+	asprintf (&homeplugins, "%s/.compiz-1/metadata", home);
 	if (homeplugins)
 	{
 	    loadPluginsFromXMLFiles (context, homeplugins);
@@ -3027,7 +2977,7 @@ ccsLoadPlugins (CCSContext * context)
     if (home && strlen (home))
     {
 	char *homeplugins = NULL;
-	asprintf (&homeplugins, "%s/.compiz/plugins", home);
+	asprintf (&homeplugins, "%s/.compiz-1/plugins", home);
 	if (homeplugins)
 	{
 	    loadPluginsFromName (context, homeplugins);
